.. _multi_physics-piezo_elasticity_macro:

multi_physics/piezo_elasticity_macro.py
=======================================

**Description**


Piezo-elasticity problem - homogenization of a piezoelectric linear elastic
matrix with embedded metalic electrodes, see [1] for details.

[1] E.Rohan, V.Lukes: Homogenization of the fluid-saturated piezoelectric
porous media. International Journal of Solids and Structures 147, 2018,
pages 110-125. https://doi.org/10.1016/j.ijsolstr.2018.05.017


.. image:: /../doc/images/gallery/multi_physics-piezo_elasticity_macro.png


:download:`source code </../sfepy/examples/multi_physics/piezo_elasticity_macro.py>`

.. literalinclude:: /../sfepy/examples/multi_physics/piezo_elasticity_macro.py

